Installation
============

The package is under active development. Stable releases can be installed from the official Python repositories, which are updated frequently.

Installing the `repository version <https://pypi.org/project/econpizza/>`_ from PyPi is as simple as typing

.. code-block:: bash

   pip install econpizza

in your terminal or Anaconda Prompt.

The current version is supporting Python versions 3.9 to 3.11 on Windows, Mac and Linux.
The `changelog and release history <https://github.com/gboehl/econpizza/releases>`_ can be found on GitHub.
